package eu.dty.attributor

import com.fasterxml.jackson.databind.ObjectMapper
import com.fasterxml.jackson.datatype.jdk8.Jdk8Module
import com.fasterxml.jackson.module.kotlin.KotlinModule
import io.r2dbc.spi.ConnectionFactory
import io.swagger.v3.oas.models.OpenAPI
import io.swagger.v3.oas.models.info.Info
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.autoconfigure.r2dbc.ConnectionFactoryBuilder
import org.springframework.boot.autoconfigure.r2dbc.R2dbcProperties
import org.springframework.boot.info.BuildProperties
import org.springframework.context.annotation.Bean
import org.springframework.context.annotation.Configuration
import org.springframework.context.annotation.Profile
import org.springframework.data.r2dbc.config.AbstractR2dbcConfiguration
import org.springframework.data.r2dbc.repository.config.EnableR2dbcRepositories
import org.springframework.r2dbc.connection.R2dbcTransactionManager
import org.springframework.scheduling.annotation.EnableScheduling
import org.springframework.scheduling.annotation.SchedulingConfigurer
import org.springframework.scheduling.config.ScheduledTaskRegistrar
import org.springframework.transaction.ReactiveTransactionManager
import org.springframework.transaction.reactive.TransactionalOperator
import org.springframework.web.reactive.config.CorsRegistry
import org.springframework.web.reactive.config.EnableWebFlux
import org.springframework.web.reactive.config.WebFluxConfigurer
import org.springframework.web.reactive.config.WebFluxConfigurerComposite
import java.net.http.HttpClient
import java.util.concurrent.ExecutorService
import java.util.concurrent.Executors

@Configuration
@EnableWebFlux
@EnableR2dbcRepositories
class AppConfig(private val r2dbcProperties: R2dbcProperties, @Autowired(required = false) val buildInfo: BuildProperties? ) : AbstractR2dbcConfiguration() {

    // connection factory to connect to the postgres database
    @Bean
    override fun connectionFactory(): ConnectionFactory {
        val factoryBuilder = ConnectionFactoryBuilder.of(r2dbcProperties, null)
        return factoryBuilder.build()
    }

    // open API
    @Bean
    fun customOpenAPI(): OpenAPI? {
        return OpenAPI().info(
            Info().title("Attributor")
                .version(buildInfo?.version)
                .description("Attributor Backend Application.")
        )
    }

    @Bean
    fun jacksonObjectMapper(): ObjectMapper {
        var mapper = ObjectMapper()
        mapper.registerModule(Jdk8Module())
        mapper.registerModule(KotlinModule())
        return mapper
    }
}

@Configuration
@Profile("develop")
class DevConfiguration {

    @Bean
    fun corsConfigurer(): WebFluxConfigurer? {
        return object : WebFluxConfigurerComposite() {
            override fun addCorsMappings(registry: CorsRegistry) {
                registry.addMapping("/**").allowedOrigins("*")
                    .allowedMethods("*").exposedHeaders("")
            }
        }
    }
}
/**
 *  Method to disable cors origin to connect from same origin in local
 */
//@Configuration
//@Profile("develop")
//class DevConfiguration {
//
//    @Bean
//    fun corsConfigurer(): WebFluxConfigurer? {
//        return object : WebFluxConfigurerComposite() {
//            override fun addCorsMappings(registry: CorsRegistry) {
//                registry.addMapping("/**").allowedOrigins("*")
//                    .allowedMethods("*").exposedHeaders("Authorization")
//            }
//        }
//    }
//}