package eu.dty.attributor

import io.swagger.v3.oas.annotations.OpenAPIDefinition
import io.swagger.v3.oas.annotations.enums.SecuritySchemeType
import io.swagger.v3.oas.annotations.info.Info
import io.swagger.v3.oas.annotations.security.OAuthFlow
import io.swagger.v3.oas.annotations.security.OAuthFlows
import io.swagger.v3.oas.annotations.security.SecurityScheme
import io.swagger.v3.oas.annotations.servers.Server
import org.springframework.beans.factory.annotation.Value
import org.springframework.context.annotation.Bean
import org.springframework.context.annotation.Configuration
import org.springframework.security.config.annotation.web.reactive.EnableWebFluxSecurity
import org.springframework.security.config.web.server.ServerHttpSecurity
import org.springframework.security.web.server.SecurityWebFilterChain

@Configuration
@EnableWebFluxSecurity
class WebSecurityConfig(@Value("\${spring.security.oauth2.resourceserver.jwt.jwk-set-uri}") private val jwtUri: String) {

    @Bean
    fun securityChain(httpSecurity: ServerHttpSecurity): SecurityWebFilterChain? {
        httpSecurity.authorizeExchange()
            .pathMatchers("/voucher/**").permitAll().pathMatchers(
                "favicon.ico",
                "/swagger-ui.html",
                "/actuator/health",
                "/actuator/health/**", "/oauth2-redirect.html", "/swagger-ui.html", "/v3/api-docs", "/swagger-ui/index.html", "/swagger-ui/**", "/webjars/swagger-ui/**",
                "/api/loggedin/confirm/**","/devicesConfig/**", "/deviceMetadata/**","/api/loggedin/confirm/", "/public/oauth2-redirect.html", "/v3/api-docs", "/v3/api-docs/**", "/v3/api-docs/swagger-config", "/swagger-ui-custom.html").permitAll()
            .anyExchange().authenticated()
            .and().csrf().disable().oauth2ResourceServer()
            .jwt()
        return httpSecurity.build()
    }
}
@OpenAPIDefinition(info = Info(title = "my app", description = "my desc", version = "1.0"),
    servers = [
     
        Server(
            url="http://localhost:9090/",
            description="Localhost"
        )
    ])
@SecurityScheme(name = "security_auth",
    type = SecuritySchemeType.OAUTH2,
    flows = OAuthFlows(authorizationCode = OAuthFlow(authorizationUrl = "\${springdoc.oAuthFlow.authorizationUrl}",
        tokenUrl = "\${springdoc.oAuthFlow.tokenUrl}")
    )
)
class OpenApi3Config
