package eu.dty.attributor.controller



import eu.dty.attributor.models.DeviceConfig
import eu.dty.attributor.models.DeviceMetadata
import eu.dty.attributor.service.DeviceMetadataService
import eu.dty.attributor.service.DeviceService
import io.swagger.v3.oas.annotations.security.SecurityRequirement
import org.springframework.http.HttpStatus
import org.springframework.http.MediaType
import org.springframework.web.bind.annotation.*
import org.springframework.web.server.ResponseStatusException
import reactor.core.publisher.Mono


@RestController
@RequestMapping("/devicesConfig")
@SecurityRequirement(name = "security_auth")
class DeviceController(val service: DeviceService, val deviceMetadataService: DeviceMetadataService) {

    @GetMapping("/{serial_number}")
    @ResponseStatus(HttpStatus.OK)
    fun getDeviceIdBySerialNo(@PathVariable serial_number: String?): Mono<DeviceConfig> {
        serial_number ?: throw ResponseStatusException(HttpStatus.BAD_REQUEST, "serial number provided is null")
        try {
            return service.findBySerialNumber(serial_number)
        }
        catch (ex: Exception) {
            throw ResponseStatusException(HttpStatus.NOT_FOUND, "Error occurred while retrieving Devices list", ex)
        }
    }

//    @PostMapping
//    @ResponseStatus(HttpStatus.OK)
//    fun saveMetaData(@RequestBody devMetadataReq: DeviceMetadata): Mono<DeviceMetadata> {
//        print("Inside ")
//        return deviceMetadataService.addDeviceMetadata(devMetadataReq)
//    }

}