package eu.dty.attributor.repository



import eu.dty.attributor.models.DeviceConfig
import eu.dty.attributor.models.DeviceMetadata
import org.springframework.data.r2dbc.repository.Query
import org.springframework.data.repository.reactive.ReactiveCrudRepository
import org.springframework.http.codec.multipart.FilePart
import reactor.core.publisher.Mono


/**
 * DeviceRepository class serves to perform save, retrieve, update or delete operations on data
 *
 */
interface DeviceConfigRepository : ReactiveCrudRepository<DeviceConfig, Long> {

    @Query("select d.* from devicesconfig d where d.serial_number = :serial_number")
    fun findBySerialNo(serial_number: String): Mono<DeviceConfig>
}

interface DeviceMetadataRepository : ReactiveCrudRepository<DeviceMetadata, Long> {
    @Query("UPDATE devicemetadata d set sensor_image = :file WHERE d.serial_number = :serial_number")
    fun saveFile(file: ByteArray, serial_number: String) : Mono<Void>



     @Query("SELECT d.* FROM deviceMetadata d WHERE d.serial_number = :serial_number")
    fun findByGuid(guid: String): Mono<DeviceMetadata>
}


interface ImageUploadRepository: ReactiveCrudRepository<Mono<FilePart>, Long>{


}